@@ -111,6 +111,7 @@ const std::unordered_map<std::string, RequestMethodHandler> RequestHandler::_han
 	{"SetTBarPosition", &RequestHandler::SetTBarPosition},
 
 	// Filters
+	{"GetSourceFilterKindList", &RequestHandler::GetSourceFilterKindList},
 	{"GetSourceFilterList", &RequestHandler::GetSourceFilterList},
 	{"GetSourceFilterDefaultSettings", &RequestHandler::GetSourceFilterDefaultSettings},
 	{"CreateSourceFilter", &RequestHandler::CreateSourceFilter},
@@ -125,6 +126,7 @@ const std::unordered_map<std::string, RequestMethodHandler> RequestHandler::_han
 	{"GetSceneItemList", &RequestHandler::GetSceneItemList},
 	{"GetGroupSceneItemList", &RequestHandler::GetGroupSceneItemList},
 	{"GetSceneItemId", &RequestHandler::GetSceneItemId},
+	{"GetSceneItemSource", &RequestHandler::GetSceneItemSource},
 	{"CreateSceneItem", &RequestHandler::CreateSceneItem},
 	{"RemoveSceneItem", &RequestHandler::RemoveSceneItem},
 	{"DuplicateSceneItem", &RequestHandler::DuplicateSceneItem},
