@@ -297,7 +297,7 @@ namespace Utils {
 		}
 
 		namespace SearchHelper {
-			obs_hotkey_t *GetHotkeyByName(std::string name);
+			obs_hotkey_t *GetHotkeyByName(std::string name, std::string context);
 			obs_source_t *GetSceneTransitionByName(std::string name); // Increments source ref. Use OBSSourceAutoRelease
 			obs_sceneitem_t *GetSceneItemByName(obs_scene_t *scene, std::string name,
 							    int offset = 0); // Increments ref. Use OBSSceneItemAutoRelease
